#!/bin/bash -x
#-----BEGIN PGP SIGNATURE-----
#Version: GnuPG v1.2.6 (GNU/Linux)
#Comment: 2008-11-24 ePages Software GmbH (release key) <rnd@epages.de>
#
#iD8DBQBTjuFul5jMabHSgyARAlJqAJ9LXuoMu4z2AF9BZeuJtRIgPzNHpQCfWAv6
#M+efi6LsXua3aQwjUMlij6k=
#=HM24
#-----END PGP SIGNATURE-----

export EPAGES_BACKUP_DIR=
export EPAGES_BACKUP_DB=
export EPAGES_INSTALL_VERSION=$2

# return values

NO_CURL=101
RPMIFY_FAILED=102
GET_RPMIFY_FAILED=103

APT_PATCH_FAILED=110
YUM_PATCH_FAILED=105
ZYPPER_PATCH_FAILED=104
APT_UPGRADE_FAILED=109
YUM_UPGRADE_FAILED=114

GET_REPOSITORY_FAILED=111
SET_REPOSITORY_FAILED=108
UPDATE_REPOSITORY_FAILED=112

HOTFIX_CONSOLE_FAILED=106
INSTALL_HOTFIX_FAILED=107
INSTALL_HOTFIX_BASE_FAILED=113

# export variables

export EPAGES_BACKUP_DIR=
export EPAGES_BACKUP_DB=
export EPAGES_INSTALL_VERSION=$2


type curl >/dev/null || exit $NO_CURL

if [[ -n ${EPAGES_REPO%% *} ]] ; then
  # if EPAGES_REPO is set, use this
  EPAGES_REPOSITORY=${EPAGES_REPO%% *}
elif [[ -s /etc/yum/vars/EPAGES_REPO ]] ; then
  # elif file /etc/yum/vars/EPAGES_REPO has content, use this
  EPAGES_REPOSITORY=$(cat /etc/yum/vars/EPAGES_REPO | head -1)
  EPAGES_REPOSITORY=$(echo $EPAGES_REPOSITORY | sed 's, .*,,')
fi

# patch version is older than 6.17.5 -> old method

if [[ $(printf "%d%03d%03d" ${EPAGES_INSTALL_VERSION//./ }) -lt 6017005 ]] ; then

  EPAGES_REPOSITORY=${EPAGES_REPOSITORY:-http://epages.com/RPMS}
  curl $EPAGES_REPOSITORY/rpmify/rpmify-epages.sh | sh || exit $RPMIFY_FAILED
  [[ ${PIPESTATUS[0]} = 0 ]] || exit $GET_RPMIFY_FAILED

  if [[ -f /etc/SuSE-release ]] ; then
    zypper modifyrepo --enable epages-update-$2
    zypper update -y -r epages-update-$2 epages-j
    zypper update -y -r epages-update-$2 epages-hotfix-base
    zypper update -y -r epages-update-$2 epages-patch && RET=0 || RET=$ZYPPER_PATCH_FAILED
    zypper modifyrepo --disable epages-update-$2
    exit $RET
  else
    yum -y update epages-j --disablerepo epages-update --enablerepo epages-update-$2
    yum -y update epages-hotfix-base --disablerepo epages-update --enablerepo epages-update-$2
    yum -y update epages-patch --disablerepo epages-update --enablerepo epages-update-$2 \
    || exit $YUM_PATCH_FAILED

    # install latest hotfixes
    DN=$(cd $(dirname $0) && pwd)
    InstallHotfixBase=${DN%/*}/customize/ZZ-InstallHotfixBase.sh
    if rpm --quiet -q epages-hotfix-base ; then
      /etc/cron.daily/epages-hotfix -console || exit $HOTFIX_CONSOLE_FAILED
    elif [[ -f $InstallHotfixBase ]] ; then
      chmod +x $InstallHotfixBase
      $InstallHotfixBase || exit $INSTALL_HOTFIX_FAILED
    fi
  fi

  exit 0
fi

# patch version is 6.17.5 or newer -> new method

EPAGES_REPOSITORY=${EPAGES_REPOSITORY:-http://epages.com/repo/epages}

if [[ -f /etc/debian_versions ]] ; then

  curl -O $EPAGES_REPOSITORY/apt/epages-release_all.deb || exit $GET_REPOSITORY_FAILED
  dpkg -i epages-release_all.deb || exit $UPDATE_REPOSITORY_FAILED
  /var/epages/SetRepository.sh -b $2 -r $EPAGES_REPOSITORY || exit $SET_REPOSITORY_FAILED

  apt-get --only-upgrade install 'epages-[a-oq-z]+' || exit $APT_UPGRADE_FAILED
  apt-get install epages-hotfix-base epages-patch || exit $APT_PATCH_FAILED

  rm -f /etc/yum.repos.d/epages-hotfix.repo
  /etc/cron.daily/epages-hotfix -console
  
elif [[ -f /etc/redhat-release ]] ; then

  rpm -hUv $EPAGES_REPOSITORY/yum/epages-release.noarch.rpm || exit $UPDATE_REPOSITORY_FAILED
  /var/epages/SetRepository.sh -b $2 -r $EPAGES_REPOSITORY || exit $SET_REPOSITORY_FAILED

  yum -y update 'epages-[a-oq-z]*' --disablerepo epages-setup --enablerepo epages-update \
  || exit $YUM_UPGRADE_FAILED
  yum -y update epages-patch --disablerepo epages-setup --enablerepo epages-update || {
    PATCH_RESULT="$EPAGES"/Shared/Log/epages-patch.result
    [[ -f $PATCH_RESULT && $(cat $PATCH_RESULT) = 0 ]] || exit $YUM_PATCH_FAILED
  }

  if ! rpm --quiet -q epages-hotfix-base ; then
    yum -y install epages-hotfix-base --disablerepo epages-setup --enablerepo epages-update \
    || exit $INSTALL_HOTFIX_BASE_FAILED
  fi
  /etc/cron.daily/epages-hotfix -console

fi

exit 0
