#!/bin/env perl

use strict;
use File::Basename qw(dirname);

use DE_EPAGES::Core::API::File qw ( GetFileContentLines GetFileContent DeleteFile );
use DE_EPAGES::Core::API::Script qw( RunScript );

sub Main {
    local $| = 1;

    chdir dirname $0;
    chdir '..';

    exit 0 unless -f 'filelist.txt';

    my $Version = GetFileContent('version.txt');
    chomp $$Version;

    my @DebianSkipDirs = qw(
        FileChanges/srv/epages/eproot/Cartridges/DE_EPAGES/WebInterfacePoolDB/
        FileChanges/srv/epages/eproot/Cartridges/DE_EPAGES/WebInterface/
        FileChanges/srv/epages/eproot/WebAdapter/
        FileChanges/srv/epages/eproot/Shared/Monitor/
    );

    my $Result = 0;
    foreach (@{GetFileContentLines('filelist.txt')}) {
        /^(\S+)\s+(.+)/ or next;
        my ($Size, $File) = ($1, $2); ##no critic (ProhibitCaptureWithoutTest)

        # for debian version 6.16.3, ignore some files
        if (-f '/etc/debian_version' && $$Version =~ /^6\.16\.3\./) {
            my $DeleteFile;
            foreach my $Dir (@DebianSkipDirs) {
                $DeleteFile = 1 if $File =~ /^$Dir/;
            }
            if ($DeleteFile) {
                DeleteFile($File);
                next;
            }
        }

        next if $File eq 'filelist.txt';
        if (! -f $File ) {
            print "missing: $File\n";
        } elsif ( -s $File != $Size ) {
            print "corrupt: $File\n";
            $Result = 1;
        }
    }
    exit $Result;
}

RunScript(
    'Sub' => \&Main
);
